import { Language, LanguageKey, LANGUAGES } from '@/lib/language';
import React, { createContext, useContext, useState, ReactNode } from 'react';

type LanguageContextType = {
  lang:Language;
  t:(key:LanguageKey, p?:{ [key:string]:string }) => string;
};

const LanguageContext = createContext<LanguageContextType | undefined>(undefined);

export const LanguageProvider: React.FC<{ children: ReactNode }> = ({
  children
}) => {
  const [ lang, setLang ] = useState<Language>('en');

  const t:LanguageContextType['t'] = (key, p) => {
    const str = LANGUAGES[lang][key];

    if(!str) {
      console.error(`Invalid language key: ${key}`);
      return '';
    }

    if(!p) return str;

    return Object.keys(p).reduce((acc, k, v) => {
      return acc.replace(`{{${k}}}`, p[k]);
    }, str);
  };

  return (
    <LanguageContext.Provider value={{
      lang,
      t
    }}>
      {children}
    </LanguageContext.Provider>
  );
};

export const useLanguage = (): LanguageContextType => {
  const context = useContext(LanguageContext);
  if (!context) {
    throw new Error('useLanguage must be used within a LanguageProvider');
  }
  return context;
};
